@@ -41,6 +41,38 @@ struct _Edje_Color_Class
    Eina_Stringshare *desc;
 };
 
+/**
+ * @typedef Edje_Text_Class
+ * Type for edje text class
+ *
+ * @since 1.17
+ */
+typedef struct _Edje_Text_Class Edje_Text_Class;
+
+struct _Edje_Text_Class
+{
+   const char     *name;
+   const char     *font;
+   Evas_Font_Size  size;
+};
+
+/**
+ * @typedef Edje_Size_Class
+ * Type for edje size class
+ *
+ * @since 1.17
+ */
+typedef struct _Edje_Size_Class Edje_Size_Class;
+
+struct _Edje_Size_Class
+{
+   Eina_Stringshare *name;
+   Evas_Coord        minw;
+   Evas_Coord        minh;
+   Evas_Coord        maxw;
+   Evas_Coord        maxh;
+};
+
 /**
  * @defgroup Edje_Object_Communication_Interface_Signal Edje Communication Interface: Signal
  *
@@ -1236,7 +1268,8 @@ typedef enum _Edje_Part_Type
    EDJE_PART_TYPE_LIGHT     = 14,
    EDJE_PART_TYPE_CAMERA    = 15,
    EDJE_PART_TYPE_SNAPSHOT  = 16, /**< Snapshot @since 1.16 */
-   EDJE_PART_TYPE_LAST      = 17  /**< Last type value */
+   EDJE_PART_TYPE_VECTOR    = 17, /**< Vector @since 1.18 */
+   EDJE_PART_TYPE_LAST      = 18  /**< Last type value */
 } Edje_Part_Type;
 /**
  * @}
@@ -1585,6 +1618,136 @@ EAPI void         edje_text_class_del             (const char *text_class);
  */
 EAPI Eina_List   *edje_text_class_list            (void);
 
+/**
+ * @brief Iterate over all active classes of an application.
+ *
+ * @return an iterator of Edje_Text_Class of the currently active text class
+ *
+ * This function only iterates over the Edje_Text_Class in use by
+ * an application.
+ *
+ * @since 1.17
+ *
+ */
+EAPI Eina_Iterator *edje_text_class_active_iterator_new(void);
+
+/**
+ * @brief Iterate over all text classes provided by an Edje file.
+ *
+ * @return an iterator of Edje_Text_Class provided by the Edje file.
+ *
+ * @since 1.17
+ *
+ */
+EAPI Eina_Iterator *edje_mmap_text_class_iterator_new(Eina_File *f);
+
+/**
+ * @}
+ */
+
+/**
+ * @defgroup Edje_Object_Size_Class Edje Class: Size
+ *
+ * @brief Functions that deal with Size Classes
+ *
+ * Sometimes we want to change the size of two or more parts equally and
+ * that's when we use size classes.
+ *
+ * If one or more parts are assigned with a size class, when we set attributes
+ * (minw etc.) to this class will update all these parts with the new attributes.
+ * Setting values to a size class at a process level will affect
+ * all parts with that size class, while at object level will affect only
+ * the parts inside an specified object.
+ *
+ * @ingroup Edje_Object_Group
+ *
+ * @{
+ */
+
+/**
+ * @brief Set the Edje size class.
+ *
+ * @param size_class The size class name
+ * @param minw The min width
+ * @param minh The min height
+ * @param maxw The max width
+ * @param maxh The max height
+ *
+ * @return @c EINA_TRUE, on success or @c EINA_FALSE, on error
+ *
+ * This function updates all Edje members at the process level which
+ * belong to this size class with the new min and max attributes.
+ *
+ * @see edje_size_class_get().
+ *
+ * @since 1.17
+ */
+EAPI Eina_Bool    edje_size_class_set             (const char *size_class, Evas_Coord minw, Evas_Coord minh, Evas_Coord maxw, Evas_Coord maxh);
+
+/**
+ * @brief Get the Edje size class.
+ *
+ * @param size_class The size class name
+ * @param minw The min width
+ * @param minh The min height
+ * @param maxw The max width
+ * @param maxh The max height
+ *
+ * @return @c EINA_TRUE, on success or @c EINA_FALSE, on error
+ *
+ * This function gets the min and max size from the specified Edje
+ * size class.
+ *
+ * @since 1.17
+ */
+EAPI Eina_Bool    edje_size_class_get             (const char *size_class, Evas_Coord *minw, Evas_Coord *minh, Evas_Coord *maxw, Evas_Coord *maxh);
+
+/**
+ * @brief Delete the size class.
+ *
+ * @param size_class The size class name
+ *
+ * This function deletes any values at the process level for the
+ * specified size class.
+ *
+ * @since 1.17
+ */
+EAPI void         edje_size_class_del             (const char *size_class);
+
+/**
+ * @brief List size classes.
+ *
+ * @return A list of size class names (strings). These strings are
+ * stringshares and the list must be eina_stringshare_del()'ed by the caller.
+ *
+ * This function lists all size classes known about by the current
+ * process.
+ *
+ * @since 1.17
+ */
+EAPI Eina_List   *edje_size_class_list            (void);
+
+/**
+ * @brief Iterate over all active classes of an application.
+ *
+ * @return an iterator of Edje_Size_Class of the currently active size class
+ *
+ * This function only iterates over the Edje_Size_Class in use by
+ * an application.
+ *
+ * @since 1.17
+ */
+EAPI Eina_Iterator *edje_size_class_active_iterator_new(void);
+
+/**
+ * @brief Iterate over all size classes provided by an Edje file.
+ *
+ * @return an iterator of Edje_Size_Class provided by the Edje file.
+ *
+ * @since 1.17
+ */
+EAPI Eina_Iterator *edje_mmap_size_class_iterator_new(Eina_File *f);
+
 /**
  * @}
  */
@@ -1637,6 +1800,17 @@ EAPI void              edje_mmap_collection_list_free(Eina_List *lst);
  */
 EAPI Eina_Bool         edje_mmap_group_exists(Eina_File *f, const char *glob);
 
+/**
+ * Determine whether a group have 3D Scene.
+ * @param f The mapped file
+ * @param glob The group name
+ *
+ * @return 1 if a Scene is found is found, 0 otherwise
+ *
+ * @since 1.18
+ */
+EAPI Eina_Bool         edje_mmap_3d_has(Eina_File *f, const char *group);
+
 /**
  * @brief Iterate over all the opened Edje file.
  *
@@ -2175,6 +2349,23 @@ EAPI Eina_Bool edje_audio_channel_mute_get(Edje_Channel channel);
  * @since 1.10
  */
 EAPI const char *edje_object_part_object_name_get(const Evas_Object *obj);
+
+#ifdef EFL_BETA_API_SUPPORT
+
+/**
+ * Create scene and root node which contains all 3D parts of edje object
+ * @param obj An edje part object
+ * @param root node to collect all 3D parts
+ * @param scene
+ * @return scene and root node which contains all 3D parts of edje object
+ * @note If this function returns @c EINA_FALSE, @p the scene or the root
+ * node wasn't made
+ * @since 1.18
+ */
+EAPI Eina_Bool edje_3d_object_add(Evas_Object *obj, Eo **root_node, Eo *scene);
+
+#endif
+
 /**
  * @}
  */
