@@ -15,7 +15,7 @@ typedef Eo Evas_Canvas3D_Light;
 #endif
 #define EVAS_CANVAS3D_LIGHT_CLASS evas_canvas3d_light_class_get()
 
-EAPI const Eo_Class *evas_canvas3d_light_class_get(void) EINA_CONST;
+EWAPI const Eo_Class *evas_canvas3d_light_class_get(void);
 
 /**
  * @brief Set the directional flag of the given light.
@@ -33,7 +33,7 @@ EAPI const Eo_Class *evas_canvas3d_light_class_get(void) EINA_CONST;
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_directional_set(Eina_Bool directional);
+EOAPI void evas_canvas3d_light_directional_set(Eo *obj, Eina_Bool directional);
 
 /**
  * @brief Get the directional flag of the given light.
@@ -44,7 +44,7 @@ EOAPI void  evas_canvas3d_light_directional_set(Eina_Bool directional);
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI Eina_Bool  evas_canvas3d_light_directional_get(void);
+EOAPI Eina_Bool evas_canvas3d_light_directional_get(const Eo *obj);
 
 /**
  * @brief Set the spot exponent of the given light.
@@ -62,7 +62,7 @@ EOAPI Eina_Bool  evas_canvas3d_light_directional_get(void);
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_spot_exponent_set(Evas_Real exponent);
+EOAPI void evas_canvas3d_light_spot_exponent_set(Eo *obj, Evas_Real exponent);
 
 /**
  * @brief Get the spot exponent of the given light.
@@ -73,7 +73,7 @@ EOAPI void  evas_canvas3d_light_spot_exponent_set(Evas_Real exponent);
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI Evas_Real  evas_canvas3d_light_spot_exponent_get(void);
+EOAPI Evas_Real evas_canvas3d_light_spot_exponent_get(const Eo *obj);
 
 /**
  * @brief Set the spot cutoff angle of the given light.
@@ -87,7 +87,7 @@ EOAPI Evas_Real  evas_canvas3d_light_spot_exponent_get(void);
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_spot_cutoff_set(Evas_Real cutoff);
+EOAPI void evas_canvas3d_light_spot_cutoff_set(Eo *obj, Evas_Real cutoff);
 
 /**
  * @brief Get the spot cutoff angle of the given light.
@@ -98,7 +98,7 @@ EOAPI void  evas_canvas3d_light_spot_cutoff_set(Evas_Real cutoff);
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI Evas_Real  evas_canvas3d_light_spot_cutoff_get(void);
+EOAPI Evas_Real evas_canvas3d_light_spot_cutoff_get(const Eo *obj);
 
 /**
  * @brief Set the attenuation enable flag of the given light.
@@ -111,7 +111,7 @@ EOAPI Evas_Real  evas_canvas3d_light_spot_cutoff_get(void);
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_attenuation_enable_set(Eina_Bool enable);
+EOAPI void evas_canvas3d_light_attenuation_enable_set(Eo *obj, Eina_Bool enable);
 
 /**
  * @brief Get the attenuation enable flag of the given light.
@@ -122,85 +122,91 @@ EOAPI void  evas_canvas3d_light_attenuation_enable_set(Eina_Bool enable);
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI Eina_Bool  evas_canvas3d_light_attenuation_enable_get(void);
+EOAPI Eina_Bool evas_canvas3d_light_attenuation_enable_get(const Eo *obj);
 
 /**
  * @brief Set the ambient color of the given light.
  *
  * Default ambient color is (0.0, 0.0, 0.0, 1.0).
  *
+ * @param[in] r Red component of the ambient color between [0.0, 1.0].
  * @param[in] g Green component of the ambient color between [0.0, 1.0].
  * @param[in] b Blue component of the ambient color between [0.0, 1.0].
  * @param[in] a Alpha component of the ambient color between [0.0, 1.0].
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_ambient_set(Evas_Real r, Evas_Real g, Evas_Real b, Evas_Real a);
+EOAPI void evas_canvas3d_light_ambient_set(Eo *obj, Evas_Real r, Evas_Real g, Evas_Real b, Evas_Real a);
 
 /**
  * @brief Get the ambient color of the given light.
  *
  * See also @ref evas_canvas3d_light_ambient_set
  *
+ * @param[out] r Red component of the ambient color between [0.0, 1.0].
  * @param[out] g Green component of the ambient color between [0.0, 1.0].
  * @param[out] b Blue component of the ambient color between [0.0, 1.0].
  * @param[out] a Alpha component of the ambient color between [0.0, 1.0].
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_ambient_get(Evas_Real *r, Evas_Real *g, Evas_Real *b, Evas_Real *a);
+EOAPI void evas_canvas3d_light_ambient_get(const Eo *obj, Evas_Real *r, Evas_Real *g, Evas_Real *b, Evas_Real *a);
 
 /**
  * @brief Set the diffuse color of the given light.
  *
  * Default diffuse color is (1.0, 1.0, 1.0, 1.0).
  *
+ * @param[in] r Red component of the diffuse color between [0.0, 1.0].
  * @param[in] g Green component of the diffuse color between [0.0, 1.0].
  * @param[in] b Blue component of the diffuse color between [0.0, 1.0].
  * @param[in] a Alpha component of the diffuse color between [0.0, 1.0].
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_diffuse_set(Evas_Real r, Evas_Real g, Evas_Real b, Evas_Real a);
+EOAPI void evas_canvas3d_light_diffuse_set(Eo *obj, Evas_Real r, Evas_Real g, Evas_Real b, Evas_Real a);
 
 /**
  * @brief Get the diffuse color of the given light.
  *
  * See also @ref evas_canvas3d_light_diffuse_set
  *
+ * @param[out] r Red component of the diffuse color between [0.0, 1.0].
  * @param[out] g Green component of the diffuse color between [0.0, 1.0].
  * @param[out] b Blue component of the diffuse color between [0.0, 1.0].
  * @param[out] a Alpha component of the diffuse color between [0.0, 1.0].
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_diffuse_get(Evas_Real *r, Evas_Real *g, Evas_Real *b, Evas_Real *a);
+EOAPI void evas_canvas3d_light_diffuse_get(const Eo *obj, Evas_Real *r, Evas_Real *g, Evas_Real *b, Evas_Real *a);
 
 /**
  * @brief Set the specular color of the given light.
  *
  * Default specular color is (1.0, 1.0, 1.0, 1.0).
  *
+ * @param[in] r Red component of the specular color between [0.0, 1.0].
  * @param[in] g Green component of the specular color between [0.0, 1.0].
  * @param[in] b Blue component of the specular color between [0.0, 1.0].
  * @param[in] a Alpha component of the specular color between [0.0, 1.0].
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_specular_set(Evas_Real r, Evas_Real g, Evas_Real b, Evas_Real a);
+EOAPI void evas_canvas3d_light_specular_set(Eo *obj, Evas_Real r, Evas_Real g, Evas_Real b, Evas_Real a);
 
 /**
  * @brief Get the specular color of the given light.
  *
  * See also @ref evas_canvas3d_light_specular_set
  *
+ * @param[out] r Red component of the specular color between [0.0, 1.0].
  * @param[out] g Green component of the specular color between [0.0, 1.0].
  * @param[out] b Blue component of the specular color between [0.0, 1.0].
  * @param[out] a Alpha component of the specular color between [0.0, 1.0].
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_specular_get(Evas_Real *r, Evas_Real *g, Evas_Real *b, Evas_Real *a);
+EOAPI void evas_canvas3d_light_specular_get(const Eo *obj, Evas_Real *r, Evas_Real *g, Evas_Real *b, Evas_Real *a);
 
 /**
  * @brief Set the attenuation of the given light.
@@ -215,24 +221,26 @@ EOAPI void  evas_canvas3d_light_specular_get(Evas_Real *r, Evas_Real *g, Evas_Re
  *
  * See also @ref evas_canvas3d_light_attenuation_enable_set
  *
+ * @param[in] constant Constant attenuation term..
  * @param[in] linear Linear attenuation term..
  * @param[in] quadratic Quadratic attenuation term..
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_attenuation_set(Evas_Real constant, Evas_Real linear, Evas_Real quadratic);
+EOAPI void evas_canvas3d_light_attenuation_set(Eo *obj, Evas_Real constant, Evas_Real linear, Evas_Real quadratic);
 
 /**
  * @brief Get the attenuation of the given light.
  *
  * See also @ref evas_canvas3d_light_attenuation_set
  *
+ * @param[out] constant Constant attenuation term..
  * @param[out] linear Linear attenuation term..
  * @param[out] quadratic Quadratic attenuation term..
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_attenuation_get(Evas_Real *constant, Evas_Real *linear, Evas_Real *quadratic);
+EOAPI void evas_canvas3d_light_attenuation_get(const Eo *obj, Evas_Real *constant, Evas_Real *linear, Evas_Real *quadratic);
 
 /**
  * @brief Set the projection matrix of the given light source.
@@ -248,7 +256,7 @@ EOAPI void  evas_canvas3d_light_attenuation_get(Evas_Real *constant, Evas_Real *
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_projection_matrix_set(const Evas_Real *matrix);
+EOAPI void evas_canvas3d_light_projection_matrix_set(Eo *obj, const Evas_Real *matrix);
 
 /**
  * @brief Get the projection matrix of the given light source.
@@ -259,7 +267,7 @@ EOAPI void  evas_canvas3d_light_projection_matrix_set(const Evas_Real *matrix);
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_projection_matrix_get(Evas_Real *matrix);
+EOAPI void evas_canvas3d_light_projection_matrix_get(const Eo *obj, Evas_Real *matrix);
 
 /**
  * @brief Set the projection matrix of the given light source with perspective
@@ -267,13 +275,14 @@ EOAPI void  evas_canvas3d_light_projection_matrix_get(Evas_Real *matrix);
  *
  * See also @ref evas_canvas3d_light_projection_matrix_set
  *
+ * @param[in] fovy Field of view angle in Y direction.
  * @param[in] aspect Aspect ratio.
  * @param[in] dnear Distance to near clipping plane.
  * @param[in] dfar Distance to far clipping plane.
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_projection_perspective_set(Evas_Real fovy, Evas_Real aspect, Evas_Real dnear, Evas_Real dfar);
+EOAPI void evas_canvas3d_light_projection_perspective_set(Eo *obj, Evas_Real fovy, Evas_Real aspect, Evas_Real dnear, Evas_Real dfar);
 
 /**
  * @brief Set the projection matrix of the given light source with frustum
@@ -281,6 +290,7 @@ EOAPI void  evas_canvas3d_light_projection_perspective_set(Evas_Real fovy, Evas_
  *
  * @ref evas_canvas3d_light_projection_matrix_set
  *
+ * @param[in] left Left X coordinate of the near clipping plane.
  * @param[in] right Right X coordinate of the near clipping plane.
  * @param[in] bottom Bottom Y coordinate of the near clipping plane.
  * @param[in] top Top Y coordinate of the near clipping plane
@@ -289,7 +299,7 @@ EOAPI void  evas_canvas3d_light_projection_perspective_set(Evas_Real fovy, Evas_
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_projection_frustum_set(Evas_Real left, Evas_Real right, Evas_Real bottom, Evas_Real top, Evas_Real dnear, Evas_Real dfar);
+EOAPI void evas_canvas3d_light_projection_frustum_set(Eo *obj, Evas_Real left, Evas_Real right, Evas_Real bottom, Evas_Real top, Evas_Real dnear, Evas_Real dfar);
 
 /**
  * @brief Set the projection matrix of the given light source with orthogonal
@@ -297,6 +307,7 @@ EOAPI void  evas_canvas3d_light_projection_frustum_set(Evas_Real left, Evas_Real
  *
  * See also @ref evas_canvas3d_light_projection_matrix_set
  *
+ * @param[in] left Left X coordinate of the near clipping plane.
  * @param[in] right Right X coordinate of the near clipping plane.
  * @param[in] bottom Bottom Y coordinate of the near clipping plane.
  * @param[in] top Top Y coordinate of the near clipping plane
@@ -305,7 +316,7 @@ EOAPI void  evas_canvas3d_light_projection_frustum_set(Evas_Real left, Evas_Real
  *
  * @ingroup Evas_Canvas3D_Light
  */
-EOAPI void  evas_canvas3d_light_projection_ortho_set(Evas_Real left, Evas_Real right, Evas_Real bottom, Evas_Real top, Evas_Real dnear, Evas_Real dfar);
+EOAPI void evas_canvas3d_light_projection_ortho_set(Eo *obj, Evas_Real left, Evas_Real right, Evas_Real bottom, Evas_Real top, Evas_Real dnear, Evas_Real dfar);
 
 
 #endif
